SystemOrganization addCategory: #'Mondrian-Easel'!

!MOCanvas methodsFor: '*Mondrian-Easel' stamp: 'SantiagoVidal 6/14/2011 09:43'!
exportAsHTML
| name produceHTMLFile htmlName |
	name := UIManager default request: 'Enter a file name' initialAnswer: 'graph.html'.
	name isNil ifTrue: [ ^ self ].
	FileStream 
		forceNewFileNamed: name 
		do: [ :stream | self exportAsHTMLOn: stream ].
	! !

!MOCanvas methodsFor: '*Mondrian-Easel' stamp: 'SantiagoVidal 6/14/2011 09:43'!
exportAsHTMLOn: aStream
	| visitor |
	visitor := MOHTLMVisitor stream: aStream.
	self root acceptVisitor: visitor.! !

!MOCanvas methodsFor: '*Mondrian-Easel' stamp: 'SantiagoVidal 5/22/2011 15:46'!
exportAsSVG
	| name produceHTMLFile htmlName |
	name := UIManager default request: 'Enter a file name' initialAnswer: 'graph.svg'.
	name isNil ifTrue: [ ^ self ].
	FileStream 
		forceNewFileNamed: name 
		do: [ :stream | self exportAsSVGOn: stream ].
		
	produceHTMLFile := UIManager default confirm: 'Do you want to produce its associated html file?'. 

	produceHTMLFile ifTrue: [
		htmlName := name, '.html'.
		(name includes: $.)
			ifTrue: [ htmlName := (name copyUpToLast: $.), '.html' ].
		
		FileStream 
			forceNewFileNamed: htmlName 
			do: [ :stream | stream nextPutAll: '<html>
<embed src="', name ,'" width="', root bounds width asString,'" height="',root bounds height asString,'">
</html>' ].

	].! !

!MOCanvas methodsFor: '*Mondrian-Easel' stamp: 'EduardoFrias 12/15/2010 17:18'!
exportAsSVGOn: aStream
	| visitor |
	visitor := MOSVGVisitor stream: aStream.
	self root acceptVisitor: visitor.
	! !

Object subclass: #MOEasel
	instanceVariableNames: 'window canvas canvasScrollPane textEditor view variableBindings'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

MOEasel class
	instanceVariableNames: 'previousScripts'!

!MOEasel commentStamp: '<historical>' prior: 0!
MOEasel represents an Easel. It is a central class in Mondrian.

Class collaborations
	MOGraphElement MORoot MOImageShape MONLinearNormalizer MondrianIcons MOScatterplotLayout MOViewRenderer MOEaselCommandPNGExporter MONExplicitIdentityNormalizer MOEaselCommandHelp MOShapeSelector MOEaselCommandTutorial MOAbstractGraphLayout MOGridLayout MODashedLineShape MOEaselCommand MOAbstractFlowLayout MOCanvas MOBoundedShape MOAbstractLineLayout MOEaselCommandUpdateMondrian MOArrowedOrthoVerticalLineShape MOSpringLayout UMLClassDiagram MONumberLinearNormalizer MOAnnouncer MOEaselCommandTikzExporter MOEaselCommandSVGExporter XKCDColor MOEaselCommandAbout MOExamples MOArrowedOrthoHorizontalLineShape MOEaselCommandXMLExporter MOLineShape MOEaselCommandBMPExporter MOEaselCommandZoomOut MOEaselCommandZoomIn MOShape MOLayout MOFormsBuilder MOFilledShape MOEaselCommandDebugView MONAbstractNormalizer MOEaselCommandQuit MOEaselCommandGIFExporter 

Class public API
		#accept	#accept:notifying:	#allCommandClasses	#canvas	#closeEasel	#decreaseZoom	#disableErrorFlag	#evaluate:notify:	#fillDockingBar:usingFont:	#generate	#getButtonForWindow:	#guessTypeForName:	#hasBindingThatBeginsWith:	#helpMenu	#icon	#increaseZoom	#initializeButtonsIn:	#menu:shifted:	#menu:shifted:selection:	#menuCommandOn:	#namedTempAt:	#open	#openOn:	#openWithTitle:	#openWithTitle:	#previousScripts	#stopAllProcesses	#userCommands	#variableBindings:	#variableSelection:

Testing classes
	MondrianTest MondrianExporterSVGTest MOEaselTest 

Instance Variables:
	window --  Instance of the SystemWindow.
	canvas --  Canvas that is used
	canvasScrollPane --  scrollPane
	textEditor --  Text editor
	view -- Instance of MOViewRenderer
	variableBindings --  Dictionary #variableName -> values

Class Instance Variables:
	previousScripts --  List of the previous scripts that were executed.


Comments written by AlexandreBergel on 28 April 2011
!

MOEasel class
	instanceVariableNames: 'previousScripts'!

!MOEasel classSide methodsFor: 'menu' stamp: 'tg 11/5/2010 21:14'!
icon
	^ MondrianIcons mondrian! !

!MOEasel classSide methodsFor: 'class initialization' stamp: 'AlexandreBergel 5/16/2011 09:39'!
initialize
	self environment
		at: #TheWorldMenu
		ifPresent: [ :class | 
			((class respondsTo: #registerOpenCommand:)
				and: [ (class class >> #registerOpenCommand: sendsSelector: #deprecated:) not ])
				ifTrue: [ 
					class
						registerOpenCommand:
							{'Mondrian Easel'.
							{self.
							#open}} ] ].	"Set descent font"
	self setBalloonColor! !

!MOEasel classSide methodsFor: 'menu' stamp: 'TudorGirba 6/8/2012 22:17'!
menuCommandOn: aBuilder
	<worldMenu>

	(aBuilder item: #'MondrianEasel')
		order: 3; 
		parent: #Tools;
		label: 'Mondrian Easel';
		icon: self icon;
		action:[MOEasel open]! !

!MOEasel classSide methodsFor: 'instance creation' stamp: 'Alexandre.Bergel 8/26/2009 17:48'!
open
	"^ MOEaselBuilder open: self new."
	^self new open! !

!MOEasel classSide methodsFor: 'instance creation' stamp: 'Alexandre Bergel 12/19/2009 16:29'!
openOn: bindingsOrABinding
	| easel |
	bindingsOrABinding isCollection
		ifTrue: [ easel := self new. bindingsOrABinding do: [:bind | easel addBinding: bind ]. ^ easel open].
	^self new addBinding: bindingsOrABinding; open! !

!MOEasel classSide methodsFor: 'instance creation' stamp: 'Alexandre Bergel 12/17/2009 01:43'!
openWithTitle: aTitle

	^self new openWithTitle: aTitle ! !

!MOEasel classSide methodsFor: 'previousscript' stamp: 'Alexandre Bergel 7/26/2010 10:16'!
previousScripts
	^ previousScripts ifNil: [ previousScripts := OrderedCollection new ]! !

!MOEasel classSide methodsFor: 'class initialization' stamp: 'AlexandreBergel 5/16/2011 09:39'!
setBalloonColor
	BalloonMorph setBalloonColorTo: BalloonMorph defaultBalloonColor	"Set descent font"! !

!MOEasel methodsFor: 'button' stamp: 'tg 5/20/2008 17:50'!
accept
	self generate.
	textEditor hasUnacceptedEdits: false! !

!MOEasel methodsFor: 'text editor' stamp: 'Alexandre.Bergel 8/26/2009 17:47'!
accept: aString notifying: aController
	textEditor := aController.
    self generate.
	^true! !

!MOEasel methodsFor: 'binding' stamp: 'tg 5/20/2008 17:36'!
addBinding: aBinding
	self addVariableNamed: aBinding key withValue: aBinding value! !

!MOEasel methodsFor: 'binding' stamp: 'tg 5/20/2008 17:34'!
addVariableNamed: aSymbol withValue: aValue
	self variableBindings at: aSymbol put: aValue! !

!MOEasel methodsFor: 'interface opening' stamp: 'EduardoFrias 12/15/2010 17:43'!
allCommandClasses
	^ MOEaselCommand allSubclasses select: [:cls | cls easelClasses includes: self class ]! !

!MOEasel methodsFor: 'binding' stamp: 'Alexandre Bergel 3/4/2010 14:17'!
allVariableKeys
	| keysCopy |
	keysCopy := self variableBindings keys asOrderedCollection copy.
	^ keysCopy add: #view; yourself! !

!MOEasel methodsFor: 'binding' stamp: 'tg 5/20/2008 17:39'!
bindingOf: aSymbol
    ^ self variableBindings associationAt: aSymbol ifAbsent: [
		aSymbol asSymbol = #view ifTrue: [aSymbol -> view] ifFalse: [nil]
	]! !

!MOEasel methodsFor: 'accessing' stamp: 'jannik.laval 5/15/2009 17:25'!
canvas
	^ canvas! !

!MOEasel methodsFor: 'menu' stamp: 'Alexandre Bergel 12/17/2009 15:39'!
closeEasel
	(UIManager default confirm: 'Are you sure to close the Easel?')
		ifTrue: [ window delete ]! !

!MOEasel methodsFor: 'hooks' stamp: 'Alexandre Bergel 6/26/2010 13:03'!
configureView: aViewRenderer
	"Override this method to insert your particularization"! !

!MOEasel methodsFor: 'zoom' stamp: 'simondenier 10/27/2009 16:36'!
decreaseZoom

	self canvas root decreaseZoom.
	self canvas root updateWindow.! !

!MOEasel methodsFor: 'error management' stamp: 'Alexandre.Bergel 9/25/2009 19:53'!
disableErrorFlag
	canvas disableErrorFlag! !

!MOEasel methodsFor: 'button' stamp: 'tg 5/20/2008 15:46'!
doButtonLabel
	^'Generate View'! !

!MOEasel methodsFor: 'button' stamp: 'AlexandreBergel 1/5/2011 09:59'!
evaluate: text notify: textEdit

	Compiler new
		evaluate: text 
		in: self getContext
		to: self 
		notifying: textEdit 
		ifFail: [ self error: 'error here' ] 
		logged: false.

	"Compiler 
		evaluate: text
		notifying: textEdit
		logged: false."
! !

!MOEasel methodsFor: 'interface opening' stamp: 'AlexandreBergel 9/16/2010 21:19'!
fillDockingBar: dock usingFont: menuBarFont
	| commands groups menuMorph |
	commands := MOEaselCommand commandsForEasel: self.

	commands := commands select: #isMenu.
	groups := OrderedCollection new.
	commands do: [:c | (groups includes: c group) ifFalse: [ groups add: c group] ].

	groups do: [:groupName |
		
		menuMorph := MenuMorph new.
		commands do: [ :command |
			((command group = groupName) and: [ command class canUnderstand: #execute ] ) 
				ifTrue: [ menuMorph add: command title target: command selector: #execute ] ].
		menuMorph hasItems 
			ifTrue: [
				dock 
				add: groupName translated
				font: menuBarFont
				icon: nil
				help: groupName translated
				subMenu: menuMorph ].
	].

	dock 
			add: 'Previous scripts' translated
			font: menuBarFont
			icon: nil
			help: 'Export' translated
			subMenu: self previousScriptMenu.

	dock 
			add: 'Examples' translated
			font: menuBarFont
			icon: nil
			help: 'Examples' translated
			subMenu: self helpMenu.

! !

!MOEasel methodsFor: 'button' stamp: 'AlexandreBergel 9/5/2010 17:21'!
generate
	self stopAllProcesses.
	view := self viewRendererClass new.
	view setDefaultHandlers.
	view setDefaultHandlerForWindow: window.
	
	"This is a hook. Empty in MOEasel"
	self configureView: view. 
	
	"view setUsefulHandlersForNodes."
	self storeScript.
	self disableErrorFlag.

	self evaluate: textEditor text notify: textEditor.
	
	canvasScrollPane scroller removeMorph: canvas.
	canvas := MOCanvas on: view root.
	canvas initializeHanders.
	canvasScrollPane scroller addMorph: canvas.
	
	"(window submorphThat: [:m | m isKindOf: ScrollPane] ifNone: [nil])
		submorphs at: 1 put: canvas."
	"Horible hack"
	(window submorphs 
		detect: [:each | each class == ScrollPane]) scroller
	 		submorphs at: 1 put: canvas.

	canvas updateBounds.
! !

!MOEasel methodsFor: 'interface opening' stamp: 'AlexandreBergel 4/13/2011 08:55'!
getButtonForWindow: aWin
	| commands |
	commands := self userCommands.
	commands := commands select: #isButton.
	^ commands
		collect: [ :command | 
			command icon
				ifNotNil: [ 
					(aWin
						newButtonFor: command
						getState: #isActive
						action: #execute
						arguments: #()
						getEnabled: nil
						labelForm: command icon
						help: command title)
						valueOfProperty: #noBorder ifAbsentPut: [ true ];
						valueOfProperty: #noFill ifAbsentPut: [ true ];
						yourself	"			getLabel: #title
		"	"this is a hack to tell the glamorous theme not to fill or draw borders" ]
				ifNil: [ 
					aWin
						newButtonFor: command
						getState: #isActive
						action: #execute
						arguments: #()
						getEnabled: nil
						getLabel: #title
						help: command title ] ]! !

!MOEasel methodsFor: 'accessing' stamp: 'AlexandreBergel 1/5/2011 10:06'!
getContext
	^ self
	"^ MOEaselContext fromEasel: self"! !

!MOEasel methodsFor: 'binding-completion' stamp: 'lr 7/7/2010 08:30'!
guessTypeForName: aString
	aString = 'view'
		ifTrue: [ ^ self viewRendererClass ].
	variableBindings
		at: aString
		ifPresent: [ :value | ^ value class ].
	^ nil! !

!MOEasel methodsFor: 'binding' stamp: 'AlexandreBergel 11/24/2010 10:13'!
hasBindingOf: aString
   ^ (self bindingOf: aString) notNil! !

!MOEasel methodsFor: 'binding' stamp: 'AlexandreBergel 4/11/2011 16:07'!
hasBindingThatBeginsWith: aString
	^ self allVariableKeys anySatisfy: [:each | each beginsWith: aString]! !

!MOEasel methodsFor: 'help' stamp: 'AlexandreBergel 9/16/2010 21:20'!
helpClass
	^ MOEaselExamples! !

!MOEasel methodsFor: 'help' stamp: 'AlexandreBergel 9/6/2010 18:29'!
helpMenu
	| menuMorph |
	menuMorph := MenuMorph new.
	self helpClass populateMenu: menuMorph forEasel: self.
	
	^ menuMorph ! !

!MOEasel methodsFor: 'zoom' stamp: 'simondenier 10/27/2009 16:36'!
increaseZoom

	self canvas root increaseZoom.
	self canvas root updateWindow.! !

!MOEasel methodsFor: 'interface opening' stamp: 'Alexandre Bergel 3/2/2010 21:38'!
initialExtent

	^ RealEstateAgent standardWindowExtent! !

!MOEasel methodsFor: 'interface opening' stamp: 'tg 9/5/2010 00:11'!
initializeButtonsIn: aWin

	| dock buttons tools offset |
	dock := aWin newToolDockingBar.
	buttons := self getButtonForWindow: aWin.			
			
	tools := aWin newToolbar: buttons.
	self fillDockingBar: dock usingFont: aWin theme menuBarFont.

	dock addMorphBack: tools.
	offset := dock minExtent y.
	aWin 
		addMorph: dock
		fullFrame: (LayoutFrame 
					fractions: (0 @ 0 corner: 1 @ 0)
					offsets: (0 @ 0 corner: 0 @ offset))
"
	| zoomIncButton zoomDecButton |
	zoomIncButton := PluggableButtonMorph
				on: self root
				getState: #isZoomOn
				action: #increaseZoom
				label: #zoomIncLabel.
	aWindow 
		addMorph: zoomIncButton
		fullFrame: (LayoutFrame fractions: (0 @ 0 corner: 0.5 @ 0) offsets: (0 @ 0 corner: 0 @ 24)).

	zoomDecButton := PluggableButtonMorph
				on: self root
				getState: #isZoomOn
				action: #decreaseZoom
				label: #zoomDecLabel.
	aWindow 
		addMorph: zoomDecButton
		fullFrame: (LayoutFrame fractions: (0.5 @ 0 corner: 1 @ 0) offsets: (0 @ 0 corner: 0 @ 24)).
"! !

!MOEasel methodsFor: 'interface opening' stamp: 'AlexandreBergel 4/11/2011 16:33'!
initializeTextEditor
	| styler |
	textEditor := MorphicTextEditor default
		on: self
		text: #text
		accept: #accept:notifying:
		readSelection: #selection
		menu: #menu:shifted:.
	textEditor
		font: StandardFonts codeFont;
		borderWidth: 0;
		vResizing: #spaceFill;
		hResizing: #spaceFill.
	styler := (SHTextStylerST80 new)
		view: textEditor;
		workspace: self;
		yourself.	"This is necessary for making the easel work on Pharo 1.1.1"
	(textEditor class canUnderstand: #styler:)
		ifTrue: [ textEditor styler: styler ]! !

!MOEasel methodsFor: 'binding-completion' stamp: 'EstebanLorenzano 4/18/2012 09:58'!
isCodeCompletionAllowed 
	^true! !

!MOEasel methodsFor: 'button' stamp: 'Alexandre Bergel 12/17/2009 15:45'!
isOn
	^false! !

!MOEasel methodsFor: 'hooks' stamp: 'Alexandre Bergel 6/26/2010 11:31'!
label
	^ 'Mondrian Easel'! !

!MOEasel methodsFor: 'menu' stamp: 'Alexandre Bergel 7/8/2010 11:33'!
menu: aMenuMorph shifted: aFalse 
	^ aMenuMorph ! !

!MOEasel methodsFor: 'text editor' stamp: 'Alexandre Bergel 12/17/2009 00:34'!
menu: aMenuMorph shifted: aFalse selection: anOBTextSelection
	aMenuMorph add: 'previous script...' translated
		target: self
		action: #retrievingPreviousScript.
	^ aMenuMorph! !

!MOEasel methodsFor: 'binding' stamp: 'AlexandreBergel 2/17/2011 09:57'!
method
	^ MOEasel >> #method! !

!MOEasel methodsFor: 'binding' stamp: 'AlexandreBergel 11/24/2010 10:35'!
namedTempAt: index
	^ variableBindings at: (self tempNames at: index)
! !

!MOEasel methodsFor: 'accessing' stamp: 'Alexandre.Bergel 8/30/2009 13:39'!
numberOfPreviousScripts
	^ self previousScripts size! !

!MOEasel methodsFor: 'interface opening' stamp: 'Alexandre Bergel 6/26/2010 11:31'!
open
	^ self openWithTitle: self label! !

!MOEasel methodsFor: 'interface opening' stamp: 'AlexandreBergel 4/11/2011 16:33'!
openWithTitle: aTitle
	| doButton variableList |
	"This is necessary for making the easel work on Pharo 1.1.1"
	window := StandardWindow labelled: aTitle.
	window model: self.
	window extent: 640 @ 480.
	canvasScrollPane := ScrollPane new.
	canvas := MOCanvas on: MORoot new.
	self initializeButtonsIn: window.
	canvas initializeHanders.
	canvasScrollPane scroller addMorph: canvas.
	window
		addMorph: canvasScrollPane
		fullFrame: (LayoutFrame fractions: (0 @ 0 corner: 1 @ 0.6) offsets: (0 @ 26 corner: 0 @ 0)).	"frame: (0 @ 0 corner: 1 @ 0.6)."
	self initializeTextEditor.
	window
		addMorph: textEditor
		fullFrame: (LayoutFrame fractions: (0 @ 0.6 corner: 0.75 @ 1) offsets: (0 @ 0 corner: 0 @ -25)).
	doButton := PluggableButtonMorph
		on: self
		getState: #isOn
		action: #accept
		label: #doButtonLabel.
	window addMorph: doButton fullFrame: (LayoutFrame fractions: (0 @ 1 corner: 0.75 @ 1) offsets: (0 @ -25 corner: 0 @ 0)).
	variableList := PluggableListMorph
		on: self
		list: #variableBindingNames
		selected: #variableSelection
		changeSelected: #variableSelection:.
	window addMorph: variableList fullFrame: (LayoutFrame fractions: (0.75 @ 0.6 corner: 1 @ 1)).
	window openInWorld.
	canvas updateBounds.
	^ window! !

!MOEasel methodsFor: 'interface opening' stamp: 'Alexandre Bergel 3/21/2010 21:22'!
previousScriptMenu
	| previousScriptMenu pScripts index |
	previousScriptMenu := MenuMorph new.
	self previousScripts ifEmpty: [ 
			previousScriptMenu
				add: 'No previous script'
				target: self
				selector: #yourself.
				^ previousScriptMenu ].
	
	pScripts := self previousScripts collect: [:each | each copyFrom: 1 to: (each size min: 20)].
	index := 1.
	pScripts do: [ :str | 
		previousScriptMenu 
				add: str
				target: self
				selector: #setScriptNumber:
				argument: index.
		index := index + 1].

	^ previousScriptMenu! !

!MOEasel methodsFor: 'accessing' stamp: 'Alexandre Bergel 7/26/2010 10:17'!
previousScripts
	^ self class previousScripts! !

!MOEasel methodsFor: 'accessing' stamp: 'Alexandre Bergel 2/23/2010 18:26'!
removeAPreviousScript
	^ self previousScripts removeLast! !

!MOEasel methodsFor: 'binding-completion' stamp: 'lr 7/7/2010 08:23'!
selectedClassOrMetaClass
	^ nil! !

!MOEasel methodsFor: 'text editor' stamp: 'tg 5/20/2008 15:35'!
selection
	^1 to: 0! !

!MOEasel methodsFor: 'text editor' stamp: 'Alexandre Bergel 12/17/2009 01:38'!
setScript: aText
	textEditor setText: aText! !

!MOEasel methodsFor: 'text editor' stamp: 'Alexandre Bergel 3/21/2010 21:18'!
setScriptNumber: anInteger
	self setScript: (self previousScripts at: anInteger)! !

!MOEasel methodsFor: 'interface opening' stamp: 'Alexandre Bergel 6/20/2010 23:40'!
stopAllProcesses
	canvas stopAllProcesses! !

!MOEasel methodsFor: 'button' stamp: 'AlexandreBergel 4/11/2011 16:24'!
storeScript

	textEditor ifNil: [ 
		"textEditor is not set yet, nothing to store then"
		^ self].
	
	 self storeScript: textEditor text copy.
	self numberOfPreviousScripts > 10 ifTrue: [ self removeAPreviousScript ]! !

!MOEasel methodsFor: 'button' stamp: 'AlexandreBergel 4/11/2011 16:24'!
storeScript: aString
	self numberOfPreviousScripts > 0 
		ifTrue: 
			[ self previousScripts last ~= aString ifTrue: [self previousScripts addFirst: aString] ]
		ifFalse: [self previousScripts addFirst: aString].

	! !

!MOEasel methodsFor: 'binding' stamp: 'AlexandreBergel 1/5/2011 10:06'!
tempNames
	^ variableBindings keys asSortedCollection! !

!MOEasel methodsFor: 'binding' stamp: 'tg 5/20/2008 17:28'!
text
	^ textEditor isNil ifTrue: ['' asText] ifFalse: [textEditor text]! !

!MOEasel methodsFor: 'interface opening' stamp: 'AlexandreBergel 4/13/2011 08:55'!
userCommands
	^ MOEaselCommand commandsForEasel: self! !

!MOEasel methodsFor: 'binding' stamp: 'tg 8/1/2009 02:25'!
variableBindingNames
	^ self variableBindings associations collect: [:each |
		each key, '->', each value printString ]! !

!MOEasel methodsFor: 'binding' stamp: 'tg 5/20/2008 17:33'!
variableBindings
	^variableBindings ifNil: [variableBindings := Dictionary new]! !

!MOEasel methodsFor: 'binding' stamp: 'tg 5/20/2008 17:28'!
variableBindings: aCollectionOfBindings
	variableBindings := aCollectionOfBindings! !

!MOEasel methodsFor: 'binding' stamp: 'AlexandreBergel 4/11/2011 16:02'!
variableSelection
	^0! !

!MOEasel methodsFor: 'binding' stamp: 'AlexandreBergel 4/11/2011 16:02'!
variableSelection: anInteger
! !

!MOEasel methodsFor: 'hooks' stamp: 'Alexandre Bergel 6/26/2010 13:02'!
viewRendererClass 
	^ MOViewRenderer! !

!MOEasel methodsFor: 'interface opening' stamp: 'Alexandre Bergel 6/15/2010 09:06'!
windowIsClosing
	self stopAllProcesses! !

Object subclass: #MOEaselCommand
	instanceVariableNames: 'easel'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

!MOEaselCommand commentStamp: '<historical>' prior: 0!
MOEaselCommand is the root of the command supported by the Easel and MOViewRenderer.

MOEaselCommand is an abstract class. The following methods needs to be implemented
	#execute	#title

Class collaborations
	MOEasel 

Class public API
		#execute	#group	#hasIcon	#icon	#isActive	#isButton	#isMenu	#priority	#title

Testing classes
	MOEaselTest MondrianTest 

Instance Variables:
	easel --  instance of the easel.

Comments written by AlexandreBergel on 28 April 2011
!

!MOEaselCommand classSide methodsFor: 'interface opening' stamp: 'Alexandre Bergel 6/26/2010 12:08'!
allCommandClasses
	^ self allSubclasses! !

!MOEaselCommand classSide methodsFor: 'accessing' stamp: 'EduardoFrias 12/15/2010 17:52'!
commandsForEasel: easel
	"
	self commandsForEasel: nil
	"
	| answer |
	answer := easel allCommandClasses collect: #new.
	answer := answer reject: [ :obj | 
			(obj class class methodDict includesKey: #isAbstract) and: 
				[ obj class isAbstract ] ].
	answer do: [ :c | c easel: easel ].
	^ answer sortedAs: #priority! !

!MOEaselCommand classSide methodsFor: 'accessing' stamp: 'EduardoFrias 12/15/2010 17:46'!
easelClasses 
	^  { MOEasel }! !

!MOEaselCommand classSide methodsFor: 'accessing' stamp: 'Alexandre Bergel 4/2/2010 10:54'!
group
	"Return a string"
	
	^ 'unclassified'! !

!MOEaselCommand classSide methodsFor: 'querying' stamp: 'Alexandre Bergel 4/2/2010 10:22'!
groups
	^ self allSubclasses collect: #group! !

!MOEaselCommand classSide methodsFor: 'testing' stamp: 'AlexandreBergel 5/9/2011 09:05'!
isAbstract
	^ true! !

!MOEaselCommand methodsFor: 'initialize-release' stamp: 'Alexandre Bergel 4/2/2010 10:32'!
easel: anEasel
	easel := anEasel! !

!MOEaselCommand methodsFor: 'hooks' stamp: 'Alexandre Bergel 6/26/2010 11:26'!
execute
	self subclassResponsibility ! !

!MOEaselCommand methodsFor: 'initialize-release' stamp: 'Alexandre Bergel 4/2/2010 10:24'!
group
	^ self class group! !

!MOEaselCommand methodsFor: 'testing' stamp: 'tg 9/2/2010 17:11'!
hasIcon
	^ self icon notNil! !

!MOEaselCommand methodsFor: 'testing' stamp: 'AlexandreBergel 10/20/2010 16:56'!
icon 
	^ nil! !

!MOEaselCommand methodsFor: 'testing' stamp: 'Alexandre Bergel 4/2/2010 10:55'!
isActive
	^ false! !

!MOEaselCommand methodsFor: 'testing' stamp: 'Alexandre Bergel 4/2/2010 10:47'!
isButton
	^ self isMenu not! !

!MOEaselCommand methodsFor: 'testing' stamp: 'Alexandre Bergel 4/2/2010 10:43'!
isMenu
	"if false then it is a button"
	^ true! !

!MOEaselCommand methodsFor: 'hooks' stamp: 'Alexandre Bergel 4/2/2010 10:59'!
priority
	^ 5! !

!MOEaselCommand methodsFor: 'hooks' stamp: 'Alexandre Bergel 4/2/2010 10:39'!
title
	self subclassResponsibility! !

MOEaselCommand subclass: #MOEaselCommandAbout
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

!MOEaselCommandAbout commentStamp: '<historical>' prior: 0!
MOEaselCommandAbout shows the licence of Mondrian.

Class collaborations
	MOEasel MondrianHelp 

Class public API
		#execute	#license	#priority	#title

Comments written by AlexandreBergel on 28 April 2011
!

!MOEaselCommandAbout classSide methodsFor: 'accessing' stamp: 'Alexandre Bergel 4/2/2010 10:21'!
group
	^ 'Mondrian'! !

!MOEaselCommandAbout methodsFor: 'hooks' stamp: 'Alexandre Bergel 6/26/2010 12:28'!
execute
	"Identify software version"

	| text dialog width |
	text := self license.
	width := 0.
	text linesDo: [ :l | width := width max: (UITheme current textFont widthOfStringOrText: l) ].
	dialog := LongMessageDialogWindow new entryText: text.
	dialog open.
	dialog width: (width + 120 min: Display width - 50)! !

!MOEaselCommandAbout methodsFor: 'hooks' stamp: 'AlexandreBergel 10/15/2010 08:38'!
license
	^ 'Mondrian is an information visualization engine that 
lets the visualization be specified via a script. It is built in 
VisualWorks Smalltalk and Pharo, and the scripting language 
is the Smalltalk language. It is based on a graph model and 
works directly with the objects to be represented.

Website: http://www.moosetechnology.org/tools/mondrian

License: MIT
Copyright (c) 2008-2010 Alexandre Bergel
Copyright (c) 2005-2010 Tudor Girba, Michael Meyer, Mondrian Contributors


Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

From 2006 until 2008 Mondrian was released under the BSD License.

'! !

!MOEaselCommandAbout methodsFor: 'hooks' stamp: 'Alexandre Bergel 4/2/2010 11:03'!
priority
	^ 1! !

!MOEaselCommandAbout methodsFor: 'hooks' stamp: 'Alexandre Bergel 4/2/2010 10:39'!
title
	^ 'About...'! !

MOEaselCommand subclass: #MOEaselCommandDebugView
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

!MOEaselCommandDebugView commentStamp: '<historical>' prior: 0!
MOEaselCommandDebugView open a new visualization about the structure of the first. Used to understand what are the activated caches.

Class collaborations
	MOEasel 

Class public API
		#execute	#group	#priority	#title

Comments written by AlexandreBergel on 28 April 2011
!

!MOEaselCommandDebugView classSide methodsFor: 'accessing' stamp: 'AlexandreBergel 11/29/2010 16:18'!
group
	^ 'Mondrian'! !

!MOEaselCommandDebugView methodsFor: 'hooks' stamp: 'AlexandreBergel 12/3/2010 11:45'!
execute
	| view allNodes |
	view := MOViewRenderer title: 'Debugging'.
	view interaction every: 1500 do: [
			view root clear.
				view shape rectangle
								if: #hasCachedForm fillColor: Color red.
				allNodes := easel canvas root allNodes.
				view nodes: allNodes forEach: [:each |
					view nodes: each metricCaches.
					view gridLayout gapSize: 2.
				].  
				view edges: allNodes from: #owner to: #yourself.

				view treeLayout.

			view shape label.
			view node: 
				'Each box is a node of the profiled visualization. ', String cr, 
				'The red color means the activation of the bitmap cache', String cr,
				'Inner nodes are metric caches'.
			view root applyLayout. ].
	
	view open.
! !

!MOEaselCommandDebugView methodsFor: 'hooks' stamp: 'AlexandreBergel 11/29/2010 16:18'!
priority
	^ 2.2! !

!MOEaselCommandDebugView methodsFor: 'hooks' stamp: 'AlexandreBergel 11/29/2010 16:18'!
title
	^ 'Debug...'! !

MOEaselCommand subclass: #MOEaselCommandExporter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

!MOEaselCommandExporter commentStamp: '<historical>' prior: 0!
MOEaselCommandExporter is the root of the different exporter.

MOEaselCommandExporter is an abstract class. The following methods needs to be implemented

Class public API
		#canvas	#group	#isAbstract	#priority	#title

Comments written by AlexandreBergel on 28 April 2011
!

MOEaselCommandExporter subclass: #MOEaselCommandBMPExporter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

!MOEaselCommandBMPExporter commentStamp: '<historical>' prior: 0!
MOEaselCommandBMPExporter is a BMP exporter.

Class collaborations
	MOEasel 

Class public API
		#execute	#title

Comments written by AlexandreBergel on 28 April 2011
!

!MOEaselCommandBMPExporter methodsFor: 'hooks' stamp: 'AlexandreBergel 4/11/2011 16:14'!
execute
	self canvas exportAsPNG! !

!MOEaselCommandBMPExporter methodsFor: 'hooks' stamp: 'Alexandre Bergel 4/2/2010 10:40'!
title
	^ super title, 'BMP'! !

!MOEaselCommandExporter classSide methodsFor: 'accessing' stamp: 'Alexandre Bergel 4/2/2010 10:21'!
group
	^ 'Export'! !

!MOEaselCommandExporter classSide methodsFor: 'testing' stamp: 'Alexandre Bergel 7/13/2010 22:40'!
isAbstract
	^ true! !

!MOEaselCommandExporter methodsFor: 'util' stamp: 'AlexandreBergel 4/11/2011 16:12'!
canvas
	^ easel canvas! !

!MOEaselCommandExporter methodsFor: 'hooks' stamp: 'Alexandre Bergel 4/2/2010 11:03'!
priority
	^ 30! !

!MOEaselCommandExporter methodsFor: 'hooks' stamp: 'Alexandre Bergel 4/2/2010 10:40'!
title
	^ 'Export as '! !

MOEaselCommandExporter subclass: #MOEaselCommandGIFExporter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

!MOEaselCommandGIFExporter commentStamp: '<historical>' prior: 0!
MOEaselCommandGIFExporter is a GIF exporter.

Class collaborations
	MOEasel 

Class public API
		#execute	#title

Comments written by AlexandreBergel on 28 April 2011
!

!MOEaselCommandGIFExporter methodsFor: 'hooks' stamp: 'AlexandreBergel 4/11/2011 16:14'!
execute
	self canvas exportAsGIF! !

!MOEaselCommandGIFExporter methodsFor: 'hooks' stamp: 'Alexandre Bergel 4/2/2010 10:40'!
title
	^ super title, 'GIF'! !

MOEaselCommandExporter subclass: #MOEaselCommandHTMLExporter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

!MOEaselCommandHTMLExporter classSide methodsFor: 'testing' stamp: 'SantiagoVidal 5/22/2011 11:44'!
isAbstract
	^ false! !

!MOEaselCommandHTMLExporter methodsFor: 'hooks' stamp: 'SantiagoVidal 6/14/2011 09:42'!
execute
	self canvas exportAsHTML.! !

!MOEaselCommandHTMLExporter methodsFor: 'hooks' stamp: 'SantiagoVidal 6/14/2011 09:52'!
title
	^ super title, 'HTML'! !

MOEaselCommandExporter subclass: #MOEaselCommandPNGExporter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

!MOEaselCommandPNGExporter commentStamp: '<historical>' prior: 0!
MOEaselCommandPNGExporter is a PNG exporter

Class collaborations
	MOEasel 

Class public API
		#execute	#title

Comments written by AlexandreBergel on 28 April 2011
!

!MOEaselCommandPNGExporter methodsFor: 'hooks' stamp: 'AlexandreBergel 4/11/2011 16:14'!
execute
	self canvas exportAsPNG! !

!MOEaselCommandPNGExporter methodsFor: 'hooks' stamp: 'Alexandre Bergel 4/2/2010 10:40'!
title
	^ super title, 'PNG'! !

MOEaselCommandExporter subclass: #MOEaselCommandSVGExporter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

!MOEaselCommandSVGExporter commentStamp: '<historical>' prior: 0!
MOEaselCommandSVGExporter is a SVG exporter

Class collaborations
	MOEasel 

Class public API
		#execute	#isAbstract	#title

Testing classes
	MondrianExporterSVGTest 


Comments written by AlexandreBergel on 28 April 2011
!

!MOEaselCommandSVGExporter classSide methodsFor: 'testing' stamp: 'EduardoFrias 12/15/2010 17:37'!
isAbstract
	^ false! !

!MOEaselCommandSVGExporter methodsFor: 'hooks' stamp: 'AlexandreBergel 4/11/2011 16:14'!
execute
	self canvas exportAsSVG.! !

!MOEaselCommandSVGExporter methodsFor: 'hooks' stamp: 'EduardoFrias 12/15/2010 17:22'!
title
	^ super title, 'SVG'! !

MOEaselCommandExporter subclass: #MOEaselCommandTikzExporter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

!MOEaselCommandTikzExporter commentStamp: '<historical>' prior: 0!
MOEaselCommandTikzExporter is a tikZ exporter. Used to produce Latex

Class collaborations
	MOEasel 

Class public API
		#execute	#title

Comments written by AlexandreBergel on 28 April 2011
!

!MOEaselCommandTikzExporter methodsFor: 'hooks' stamp: 'AlexandreBergel 4/11/2011 16:14'!
execute
	self canvas exportAsTikz! !

!MOEaselCommandTikzExporter methodsFor: 'hooks' stamp: 'lr 12/7/2010 23:49'!
title
	^ super title , 'TikZ'! !

MOEaselCommandExporter subclass: #MOEaselCommandXMLExporter
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

!MOEaselCommandXMLExporter commentStamp: '<historical>' prior: 0!
MOEaselCommandXMLExporter is an XML exporter.

Class collaborations
	MOEasel 

Class public API
		#execute	#title

Comments written by AlexandreBergel on 28 April 2011
!

!MOEaselCommandXMLExporter methodsFor: 'hooks' stamp: 'AlexandreBergel 4/11/2011 16:13'!
execute
	self canvas exportAsXML! !

!MOEaselCommandXMLExporter methodsFor: 'hooks' stamp: 'Alexandre Bergel 7/2/2010 10:37'!
title
	^ super title, 'XML'! !

MOEaselCommand subclass: #MOEaselCommandHelp
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

!MOEaselCommandHelp commentStamp: '<historical>' prior: 0!
MOEaselCommandHelp opens a help about Mondrian

Class collaborations
	MOEasel 

Class public API
		#execute	#group	#icon	#priority	#title

Comments written by AlexandreBergel on 28 April 2011
!

!MOEaselCommandHelp classSide methodsFor: 'accessing' stamp: 'AlexandreBergel 9/16/2010 21:14'!
group
	^ 'Mondrian'! !

!MOEaselCommandHelp methodsFor: 'hooks' stamp: 'AlexandreBergel 9/16/2010 21:12'!
execute
	HelpBrowser openOn: MondrianHelp! !

!MOEaselCommandHelp methodsFor: 'hooks' stamp: 'AlexandreBergel 9/16/2010 21:13'!
priority
	^ 2! !

!MOEaselCommandHelp methodsFor: 'hooks' stamp: 'AlexandreBergel 9/16/2010 21:21'!
title
	^ 'Help...' translated ! !

MOEaselCommand subclass: #MOEaselCommandLoadExtra
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

!MOEaselCommandLoadExtra classSide methodsFor: 'accessing' stamp: 'AlexandreBergel 7/7/2011 12:30'!
group
	^ 'Mondrian'! !

!MOEaselCommandLoadExtra methodsFor: 'hooks' stamp: 'AlexandreBergel 7/7/2011 12:30'!
execute
	| answer packageInfos mcWorkingCopies |
	answer := UIManager default confirm: 'Do you want to load some addon for Mondrian?'.
	answer ifFalse: [ ^ self ].
	
	Gofer new
		squeaksource: 'Mondrian'; 
		package: 'MondrianExtra';
		load.
	! !

!MOEaselCommandLoadExtra methodsFor: 'hooks' stamp: 'AlexandreBergel 7/7/2011 12:29'!
priority
	^ 2! !

!MOEaselCommandLoadExtra methodsFor: 'hooks' stamp: 'AlexandreBergel 7/7/2011 12:29'!
title
	^ 'Load Addon'! !

MOEaselCommand subclass: #MOEaselCommandLoadEyeSee
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

!MOEaselCommandLoadEyeSee classSide methodsFor: 'accessing' stamp: 'AlexandreBergel 5/27/2011 10:04'!
group
	^ 'Mondrian'! !

!MOEaselCommandLoadEyeSee methodsFor: 'hooks' stamp: 'AlexandreBergel 11/21/2011 15:50'!
execute
	| answer packageInfos mcWorkingCopies |
	answer := UIManager default confirm: 'EyeSee is a framework to build graphics. Do you want to load itl?'.
	answer ifFalse: [ ^ self ].
	
	"We load the last version of Mondrian"
	Gofer new
		squeaksource: 'Mondrian'; 
		package: 'MondrianEyeSee';
		load.
	Gofer new
		squeaksource: 'EyeSee'; 
		package: 'ConfigurationOfEyeSee';
		load.
	(Smalltalk at: #ConfigurationOfEyeSee) perform: #loadDefault.
! !

!MOEaselCommandLoadEyeSee methodsFor: 'hooks' stamp: 'AlexandreBergel 5/27/2011 09:48'!
priority
	^ 2! !

!MOEaselCommandLoadEyeSee methodsFor: 'hooks' stamp: 'AlexandreBergel 5/27/2011 09:48'!
title
	^ 'Load EyeSee'! !

MOEaselCommand subclass: #MOEaselCommandQuit
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

!MOEaselCommandQuit commentStamp: '<historical>' prior: 0!
MOEaselCommandQuit is made to quit the easel. 

Class collaborations
	MOEasel 

Class public API
		#execute	#priority	#title

Comments written by AlexandreBergel on 28 April 2011
!

!MOEaselCommandQuit classSide methodsFor: 'accessing' stamp: 'Alexandre Bergel 4/2/2010 10:21'!
group
	^ 'Mondrian'! !

!MOEaselCommandQuit methodsFor: 'hooks' stamp: 'Alexandre Bergel 4/2/2010 10:17'!
execute
	easel closeEasel! !

!MOEaselCommandQuit methodsFor: 'hooks' stamp: 'AlexandreBergel 11/30/2010 12:37'!
priority
	^ 20! !

!MOEaselCommandQuit methodsFor: 'hooks' stamp: 'Alexandre Bergel 4/2/2010 10:39'!
title
	^ 'Quit...'! !

MOEaselCommand subclass: #MOEaselCommandTutorial
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

!MOEaselCommandTutorial commentStamp: '<historical>' prior: 0!
MOEaselCommandTutorial open the tutorial of Mondrian

Class collaborations
	MondrianTutorial MOEasel MORoot 

Class public API
		#execute	#group	#priority	#title

Testing classes
	MOEaselTest 

Comments written by AlexandreBergel on 28 April 2011
!

!MOEaselCommandTutorial classSide methodsFor: 'accessing' stamp: 'AlexandreBergel 9/17/2010 04:49'!
group
	^ 'Mondrian'! !

!MOEaselCommandTutorial methodsFor: 'hooks' stamp: 'AlexandreBergel 1/27/2011 09:40'!
execute 
	^  HelpBrowser openOn: ProfStefTutorialsHelp ! !

!MOEaselCommandTutorial methodsFor: 'hooks' stamp: 'AlexandreBergel 9/17/2010 04:48'!
priority
	^ 2! !

!MOEaselCommandTutorial methodsFor: 'hooks' stamp: 'AlexandreBergel 9/17/2010 04:49'!
title
	^ 'Tutorial...'! !

MOEaselCommand subclass: #MOEaselCommandUpdateMondrian
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

!MOEaselCommandUpdateMondrian commentStamp: '<historical>' prior: 0!
MOEaselCommandUpdateMondrian updates Mondrian by fetching the last version of it.

Class collaborations
	MOEasel 

Class public API
		#execute	#group	#priority	#title

Comments written by AlexandreBergel on 28 April 2011
!

!MOEaselCommandUpdateMondrian classSide methodsFor: 'accessing' stamp: 'AlexandreBergel 11/30/2010 10:55'!
group
	^ 'Mondrian'! !

!MOEaselCommandUpdateMondrian methodsFor: 'hooks' stamp: 'AlexandreBergel 1/2/2012 17:22'!
execute
	| answer packageInfos mcWorkingCopies |
	answer := UIManager default confirm: 'Is it okay to close the easel?'.
	answer ifFalse: [ ^ self ].

	"We make sure none of Mondrian package is dirty"
	packageInfos := PackageInfo allPackages select: [ :p | p packageName beginsWith: 'Mondrian-'].
	mcWorkingCopies := packageInfos collect: [ :pInfo | (MCPackage named: pInfo packageName) workingCopy ].
	(mcWorkingCopies detect: #needsSaving ifNone: [ nil ]) 
		ifNotNil: [ UIManager default inform: 'Mondrian has been modified. Cannot update'. ^ self ].

	"We quite the easel"
	easel closeEasel.
	
	"We load the last version of Mondrian"
	Gofer new
		squeaksource: 'Mondrian'; 
		package: 'ConfigurationOfMondrian';
		load.
	(Smalltalk at: #ConfigurationOfMondrian) lastVersion load.
	
	"We open the easel again"
	(Smalltalk at: #MOEasel) open! !

!MOEaselCommandUpdateMondrian methodsFor: 'hooks' stamp: 'AlexandreBergel 11/30/2010 10:55'!
priority
	^ 2! !

!MOEaselCommandUpdateMondrian methodsFor: 'hooks' stamp: 'AlexandreBergel 11/30/2010 11:02'!
title
	^ 'Update mondrian'! !

MOEaselCommand subclass: #MOEaselCommandZoomIn
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

!MOEaselCommandZoomIn commentStamp: '<historical>' prior: 0!
MOEaselCommandZoomIn is for zooming in a visualization.

Class collaborations
	MOEasel MondrianIcons 

Class public API
		#execute	#icon	#isMenu	#priority	#title

Comments written by AlexandreBergel on 28 April 2011
!

!MOEaselCommandZoomIn methodsFor: 'hooks' stamp: 'Alexandre Bergel 4/2/2010 10:49'!
execute
	easel increaseZoom! !

!MOEaselCommandZoomIn methodsFor: 'hooks' stamp: 'tg 11/5/2010 21:04'!
icon
	^ MondrianIcons mondrianZoomIn! !

!MOEaselCommandZoomIn methodsFor: 'testing' stamp: 'Alexandre Bergel 4/2/2010 10:55'!
isMenu
	"if false then it is a button"
	^ false! !

!MOEaselCommandZoomIn methodsFor: 'hooks' stamp: 'Alexandre Bergel 4/2/2010 11:31'!
priority
	^ 50! !

!MOEaselCommandZoomIn methodsFor: 'hooks' stamp: 'Alexandre Bergel 4/2/2010 10:53'!
title
	^ 'Zoom in'
! !

MOEaselCommand subclass: #MOEaselCommandZoomOut
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

!MOEaselCommandZoomOut commentStamp: '<historical>' prior: 0!
MOEaselCommandZoomOut is about zooming the visualization out.

Class collaborations
	MOEasel MondrianIcons 

Class public API
		#execute	#icon	#isMenu	#priority	#title

Comments written by AlexandreBergel on 28 April 2011
!

!MOEaselCommandZoomOut methodsFor: 'hooks' stamp: 'Alexandre Bergel 4/2/2010 10:49'!
execute
	easel decreaseZoom! !

!MOEaselCommandZoomOut methodsFor: 'hooks' stamp: 'tg 11/5/2010 21:04'!
icon
	^ MondrianIcons mondrianZoomOut! !

!MOEaselCommandZoomOut methodsFor: 'testing' stamp: 'Alexandre Bergel 4/2/2010 10:55'!
isMenu
	"if false then it is a button"
	^ false! !

!MOEaselCommandZoomOut methodsFor: 'hooks' stamp: 'Alexandre Bergel 4/2/2010 11:31'!
priority
	^ 51! !

!MOEaselCommandZoomOut methodsFor: 'hooks' stamp: 'Alexandre Bergel 4/2/2010 10:53'!
title
	^ 'Zoom out'! !

Object subclass: #MondrianIcons
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Mondrian-Easel'!

MondrianIcons class
	instanceVariableNames: 'icons'!

!MondrianIcons commentStamp: '<historical>' prior: 0!
MondrianIcons contains (on its class side), the list of icons used by Mondrian.

Class collaborations
	
Class public API
		#icons	#mondrian	#mondrianZoomIn	#mondrianZoomOut	#resetIcons

Class Instance Variables:
	icons --  Cache for icons

Comments written by AlexandreBergel on 28 April 2011
!

MondrianIcons class
	instanceVariableNames: 'icons'!

!MondrianIcons classSide methodsFor: 'accessing' stamp: 'tg 11/5/2010 21:02'!
icons 
	^ icons ifNil: [icons := Dictionary new]! !

!MondrianIcons classSide methodsFor: 'accessing' stamp: 'tg 11/5/2010 21:15'!
mondrian
^ self icons
		at: #mondrian ifAbsentPut: [((ColorForm
	extent: 16@16
	depth: 4
	fromArray: #( 2863311530 2863311530 2863311530 2863311530 2863267840 43690 2863268113 286304938 2863268113 286304938 2862940433 286304938 2860646673 286304938 2855600128 43690 2684398250 2258283178 2688592544 170 2688592544 2004316330 2688592544 2004316330 2688592544 2004316330 2688592544 2004316330 2688592544 2004316330 2684398240 170)
	offset: 0@0)
	colorsFromArray: #(#(0.0 0.0 0.0) #(0.0 0.686 0.28200000000000003) #(0.059000000000000004 0.059000000000000004 0.059000000000000004) #(0.28500000000000003 0.28500000000000003 0.28500000000000003) #(0.34500000000000003 0.427 0.964) #(0.423 0.423 0.423) #(0.603 0.603 0.603) #(0.729 0.125 0.117) #(0.745 0.745 0.745) #(0.78 0.78 0.78) #(0.843 0.843 0.843) #(0.0 0.0 0.0) #(0.0 0.0 0.0) #(0.0 0.0 0.0) #(0.0 0.0 0.0) #(0.0 0.0 0.0)  ))]! !

!MondrianIcons classSide methodsFor: 'accessing' stamp: 'TudorGirba 2/4/2011 22:11'!
mondrianZoomIn
^ self icons
		at: #mondrianZoomIn ifAbsentPut: [(Form
	extent: 16@16
	depth: 32
	fromArray: #( 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 1644167168 3036676096 3875536896 3875536896 3036676096 1644167168 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 419430400 3137339392 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 3137339392 419430400 16777215 16777215 16777215 16777215 16777215 16777215 3137339392 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 3137339392 16777215 16777215 16777215 16777215 16777215 1644167168 4278190080 4278190080 4278190080 4278190080 16777215 16777215 4278190080 4278190080 4278190080 4278190080 1644167168 16777215 16777215 16777215 16777215 3036676096 4278190080 4278190080 4278190080 4278190080 16777215 16777215 4278190080 4278190080 4278190080 4278190080 3036676096 16777215 16777215 16777215 16777215 3875536896 4278190080 4278190080 16777215 16777215 16777215 16777215 16777215 16777215 4278190080 4278190080 3875536896 16777215 16777215 16777215 16777215 3875536896 4278190080 4278190080 16777215 16777215 16777215 16777215 16777215 16777215 4278190080 4278190080 3875536896 16777215 16777215 16777215 16777215 3036676096 4278190080 4278190080 4278190080 4278190080 16777215 16777215 4278190080 4278190080 4278190080 4278190080 3036676096 16777215 16777215 16777215 16777215 1644167168 4278190080 4278190080 4278190080 4278190080 16777215 16777215 4278190080 4278190080 4278190080 4278190080 1644167168 16777215 16777215 16777215 16777215 16777215 3137339392 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 3137339392 16777215 16777215 16777215 16777215 16777215 16777215 419430400 3137339392 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 3137339392 419430400 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 1644167168 3036676096 3875536896 3875536896 3036676096 1644167168 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215)
	offset: 0@0)]! !

!MondrianIcons classSide methodsFor: 'accessing' stamp: 'TudorGirba 2/4/2011 22:11'!
mondrianZoomOut
^ self icons
		at: #mondrianZoomOut ifAbsentPut: [(Form
	extent: 16@16
	depth: 32
	fromArray: #( 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 1644167168 3036676096 3875536896 3875536896 3036676096 1644167168 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 419430400 3137339392 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 3137339392 419430400 16777215 16777215 16777215 16777215 16777215 16777215 3137339392 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 3137339392 16777215 16777215 16777215 16777215 16777215 1644167168 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 1644167168 16777215 16777215 16777215 16777215 3036676096 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 3036676096 16777215 16777215 16777215 16777215 3875536896 4278190080 4278190080 16777215 16777215 16777215 16777215 16777215 16777215 4278190080 4278190080 3875536896 16777215 16777215 16777215 16777215 3875536896 4278190080 4278190080 16777215 16777215 16777215 16777215 16777215 16777215 4278190080 4278190080 3875536896 16777215 16777215 16777215 16777215 3036676096 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 3036676096 16777215 16777215 16777215 16777215 1644167168 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 1644167168 16777215 16777215 16777215 16777215 16777215 3137339392 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 3137339392 16777215 16777215 16777215 16777215 16777215 16777215 419430400 3137339392 4278190080 4278190080 4278190080 4278190080 4278190080 4278190080 3137339392 419430400 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 1644167168 3036676096 3875536896 3875536896 3036676096 1644167168 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215 16777215)
	offset: 0@0)]! !

!MondrianIcons classSide methodsFor: 'utils' stamp: 'TudorGirba 2/4/2011 22:11'!
resetIcons
	icons := nil! !
MOEasel initialize!
